$(document).ready(function() {
    var table = $('#facturasCompras').DataTable({
        ajax: {
            url: 'funciones/consultaFacturasCompras.php',  // Ruta al script PHP que devuelve las facturas
            method: 'POST',
            dataSrc: function (json) {
                var data = [];
                json.forEach(function(factura) {
                    var row = {
                        factura_compra_id: factura.factura_compra_id,
                        factura_compra_numero_factura: factura.factura_compra_numero_factura,
                        factura_compra_monto: factura.factura_compra_monto,
                        factura_compra_proveedor_id: factura.factura_compra_proveedor_id,
                        factura_compra_fecha: factura.factura_compra_fecha,
                        factura_compra_estado: factura.factura_compra_estado,
                        detalles: factura.detalles
                    };
                    data.push(row);
                });
                return data;
            }
        },
        columns: [
            {
                data: null,
                defaultContent: '<button class="expand-btn btn btn-success">+</button>', // Botón de expansión
                orderable: false
            },
            { data: 'factura_compra_id' },
            { data: 'factura_compra_numero_factura' },
            { data: 'factura_compra_monto' },
            { data: 'factura_compra_proveedor_id' },
            { data: 'factura_compra_fecha' },
            { data: 'factura_compra_estado', render: function(data) { return data == 1 ? 'Activo' : 'Inactivo'; } }
        ]
    });

    // Función para manejar el click en el botón de expansión
    $('#facturasCompras tbody').on('click', 'button.expand-btn', function () {
        var tr = $(this).closest('tr');  // Fila de la tabla
        var row = table.row(tr);  // Obtener la fila de DataTable
        var data = row.data();  // Datos de la fila

        // Verificar si la fila ya está expandida
        if (row.child.isShown()) {
            // La fila ya está expandida, así que la colapsamos
            row.child.hide();
            $(this).text('+');  // Cambiar el botón a "+"
        } else {
            // Mostrar los detalles
            var detalleHtml = '<table class="table table-bordered"><thead><tr><th>Descripcion</th><th>Monto</th><th>IVA</th><th>Cta. Pago</th></tr></thead><tbody>';
            
            data.detalles.forEach(function(detalle) {
                detalleHtml += `<tr>
                    <td>${detalle.factura_compra_det_descripcion}</td>
                    <td>${detalle.factura_compra_det_monto}</td>
                    <td>${detalle.factura_compra_det_iva}</td>
                    <td>${detalle.factura_compra_det_cta_pago}</td>
                </tr>`;
            });

            detalleHtml += '</tbody></table>';

            // Agregar los detalles debajo de la fila
            row.child(detalleHtml).show();
            $(this).text('-');  // Cambiar el botón a "-"
        }
    });
});