<?php
//include("plantilla_cabecera.php");
require_once('../../joajurehegua.php');




function obtenerSiguienteNumeroDocumento(PDO $conn, $lugar, $punto_expedicion, $tipo_documento)
{
    $conn->beginTransaction();

    try {
        // Bloquear la fila de la secuencia
        $stmt = $conn->prepare("
          SELECT ultimo_valor, formateado FROM ultimo_nro_documento 
          WHERE lugar_comercial = :lugar 
            AND punto_expedicion = :punto_expedicion 
            AND tipo_documento = :tipo_documento FOR UPDATE
      ");
        $stmt->execute([
            'lugar' => $lugar,
            'punto_expedicion' => $punto_expedicion,
            'tipo_documento' => $tipo_documento
        ]);
        $resultado = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$resultado) {
            throw new Exception("Combinación de lugar, punto_expedicion y tipo de documento no encontrada");
        }

        $ultimo_valor = $resultado['ultimo_valor'];
        $nuevo_valor = $ultimo_valor + 1;

        // Actualizar el valor
        $stmt = $conn->prepare("
          UPDATE ultimo_nro_documento 
          SET ultimo_valor = :nuevo_valor 
          WHERE lugar_comercial = :lugar 
            AND punto_expedicion = :punto_expedicion 
            AND tipo_documento = :tipo_documento
      ");
        $stmt->execute([
            'nuevo_valor' => $nuevo_valor,
            'lugar' => $lugar,
            'punto_expedicion' => $punto_expedicion,
            'tipo_documento' => $tipo_documento
        ]);

        // Generar el número de documento
        if ($resultado['formateado']) {
            $nro_documento = sprintf("%s-%s-%08d", $lugar, $punto_expedicion, $nuevo_valor);
        } else {

            $nro_documento = sprintf("%08d",  $nuevo_valor);
        }

        // $nro_documento = sprintf("%08d",  $nuevo_valor);
        $conn->commit();

        return $nro_documento;
    } catch (Exception $e) {
        $conn->rollBack();
        throw $e;
    }
}

function obtenerIdCuentaMayor($conn, $concepto_caja)
{

    $sql = "SELECT  id_cuenta_mayor
    from concepto_caja 
    where codigo = :concepto
    and   estado = 1 ";
    $stmt = $conn->prepare($sql);
    $stmt->execute(array(':concepto' =>  $concepto_caja));
    $tabla = $stmt->fetch();
    if ($tabla) {
        // Filtrar los pagos parciales
        //$pagos_parciales = array_filter($tabla, function ($fila) {
        return $tabla['id_cuenta_mayor'];
    };
}



function generarGrupoId($conn)
{
    $sql = $conn->prepare('INSERT INTO nro_documento_aux (fecha) VALUES(:fecha)');
    $bind =  array(':fecha' => date("Y-m-d"));
    try {
        $sql->execute($bind);
        $grupo_id = $conn->lastInsertId();
    } catch (PDOException $Exception) {
        error_log('Error insertando: ' . json_encode($Exception));
    }
    return $grupo_id; // Un número aleatorio, puedes usar otro método más robusto
}



function quitarPuntos($input)
{
    // Utilizamos str_replace para reemplazar los puntos con una cadena vacía
    return str_replace('.', '', $input);
}


function convertirANullSiVacio($input)
{
    // Utiliza la función empty() para verificar si está vacío
    return empty($input) ? null : $input;
}
