<?php
// Incluir archivo de conexión a la base de datos
require_once('../../joajurehegua.php');

// Verificar si los datos llegaron por POST
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Obtener los datos recibidos
    $editorContent = isset($_POST['editorContent']) ? $_POST['editorContent'] : '';  // Contenido del editor
    $aporteAcumulado = isset($_POST['aporteAcumulado']) ? $_POST['aporteAcumulado'] : 0;
    $creditoID = isset($_POST['creditoID']) ? $_POST['creditoID'] : 0;
    $lineaCredito = isset($_POST['lineaCredito']) ? $_POST['lineaCredito'] : 0;
    $montoSolicitado = isset($_POST['montoSolicitado']) ? $_POST['montoSolicitado'] : 0;
    $montoTotal = isset($_POST['montoTotal']) ? $_POST['montoTotal'] : 0;
    $aporteRelacionCredito = isset($_POST['aporteRelacionCredito']) ? $_POST['aporteRelacionCredito'] : 0;
    $faltanteAporte = isset($_POST['faltanteAporte']) ? $_POST['faltanteAporte'] : 0;
    $sueldoLiquido = isset($_POST['sueldoLiquido']) ? $_POST['sueldoLiquido'] : 0;
    $otrosDescuentos = isset($_POST['otrosDescuentos']) ? $_POST['otrosDescuentos'] : 0;
    $totalIngresos = isset($_POST['totalIngresos']) ? $_POST['totalIngresos'] : 0;

    // Validación y sanitización de los datos
    $editorContent = htmlspecialchars($editorContent);
    $aporteAcumulado =  preg_replace('/\D/', '', $aporteAcumulado);
    $creditoID = intval($creditoID);
    $lineaCredito = preg_replace('/\D/', '', $lineaCredito);
    $montoSolicitado = preg_replace('/\D/', '', $montoSolicitado);
    $montoTotal = preg_replace('/\D/', '', $montoTotal);
    $aporteRelacionCredito = preg_replace('/\D/', '', $aporteRelacionCredito);
    $faltanteAporte = preg_replace('/\D/', '', $faltanteAporte);
    $sueldoLiquido = preg_replace('/\D/', '', $sueldoLiquido);
    $otrosDescuentos = preg_replace('/\D/', '', $otrosDescuentos);
    $totalIngresos = preg_replace('/\D/', '', $totalIngresos);

    // Modificar la consulta para usar parámetros nombrados
    $query = "INSERT INTO credito_analisis (
        credito_analisis_id_credito, 
        credito_analisis_aporte_acumulado, 
        credito_analisis_lineaCredito, 
        credito_analisis_montoSolicitado, 
        credito_analisis_montoTotal, 
        credito_analisis_aporteRelacion, 
        credito_analisis_faltanteAporte, 
        credito_analisis_ingresos, 
        credito_analisis_egresos, 
        credito_analisis_liquidez,
        credito_analisis_texto
    ) VALUES (
        :creditoID, 
        :aporteAcumulado, 
        :lineaCredito, 
        :montoSolicitado, 
        :montoTotal, 
        :aporteRelacionCredito, 
        :faltanteAporte, 
        :sueldoLiquido, 
        :otrosDescuentos, 
        :liquidez,
        :analisisTexto
    )";

    // Vincular los parámetros con los valores obtenidos
    $bind = array(
        ':creditoID' => $creditoID,
        ':aporteAcumulado' => $aporteAcumulado,
        ':lineaCredito' => $lineaCredito,
        ':montoSolicitado' => $montoSolicitado,
        ':montoTotal' => $montoTotal,
        ':aporteRelacionCredito' => $aporteRelacionCredito,
        ':faltanteAporte' => $faltanteAporte,
        ':sueldoLiquido' => $sueldoLiquido,
        ':otrosDescuentos' => $otrosDescuentos,
        ':liquidez' => ($totalIngresos / 2),  // cálculo de liquidez
        ':analisisTexto' => $editorContent
    );

    // Ejecutar la consulta
    try {
        $stmt = $conn->prepare($query);
        $stmt->execute($bind);


        ///actualizamos el credito al estado siguiente
        $queryUpdate = "UPDATE creditos SET estado = 2 WHERE id = :id";

        // Preparar la consulta
        $stmtUpdate = $conn->prepare($queryUpdate);

        // Vincular el id al parámetro :id
        $stmtUpdate->bindParam(':id', $creditoID, PDO::PARAM_INT);

        // Ejecutar la consulta
        $stmtUpdate->execute();
        
        // Enviar una respuesta al frontend indicando que todo salió bien
        echo json_encode(array(
            "success" => true,
            "message" => "Análisis guardado con éxito"
        ));
    } catch (PDOException $e) {
        // Capturar cualquier error de la base de datos
        echo json_encode(array(
            "success" => false,
            "message" => "Error en la base de datos: " . $e->getMessage()
        ));
    } catch (Exception $e) {
        // Capturar cualquier otro tipo de error
        echo json_encode(array(
            "success" => false,
            "message" => "Error inesperado: " . $e->getMessage()
        ));
    }
} else {
    // Si no se recibieron datos por POST
    echo json_encode(array(
        "success" => false,
        "message" => "No se recibieron datos"
    ));
}
?>
