<?php
require_once('../joajurehegua.php');
require_once('../tcpdf/tcpdf.php'); // Incluir TCPDF


$id_cliente      = isset($_POST['id_socio']) ? $_POST['id_socio'] : '';
$cedula_cliente  = isset($_POST['cedula']) ? $_POST['cedula'] : '';


$sql = "SELECT a.*, b.nombre as estado_civil, c.nombre as genero, d.nombre as pais, e.nombre as departamento, f.nombre as distrito, g.nombre as ciudad, h.nombre as barrio,
i.nombre as profesion, j.nombre as nacionalidad
FROM clientes as a 
inner join estado_civil as b on a.id_estadocivil = b.id
inner join tipo_genero as c on a.id_genero = c.id

inner join pais as d on a.id_pais = d.id
inner join departamento as e on a.id_departamento = e.id
inner join distrito as f on a.id_distrito = f.id
inner join ciudad as g on a.id_ciudad = g.id
inner join barrio as h on a.id_barrio = h.id
inner join tipo_profesion as i on a.id_profesion = i.id
inner join nacionalidad as j on a.id_nacionalidad = i.id
WHERE 1=1";

// Agregar condiciones a la consulta SQL según los filtros
if (!empty($id_cliente)) {
  $sql .= " AND a.id_cliente = :id_cliente";
}

if (!empty($cedula_cliente)) {
  $sql .= " AND a.cedula = :cedula_cliente";
}

$stmt = $conn->prepare($sql);

// Asignar parámetros a la consulta
if (!empty($id_cliente)) {
  $stmt->bindValue(':id_cliente', $id_cliente, PDO::PARAM_INT);
}

if (!empty($cedula_cliente)) {
  $stmt->bindValue(':cedula_cliente', $cedula_cliente, PDO::PARAM_INT);
}


$stmt->execute();
$resultado = $stmt->fetch();
if ($resultado) {
} else {

  echo "no hay datos";
  exit();
}


$capital           = obtener_aporte($conn, $resultado['id_cliente']);
$capitalsuscrito   = number_format($capital['capital_suscrito'], 0, '', '.');
$CapitalIntegrado  = number_format($capital['capital_integrado'], 0, '', '.');
$saldo             =  number_format($capital['capital_suscrito'] - $capital['capital_integrado'], 0, '', '.');
$saldo_mora        = number_format($capital['saldo_mora'], 0, '', '.');

$solidaridad           = obtener_solidaridad($conn, $resultado['id_cliente']);
$capitalsuscrito_s     = number_format($solidaridad['capital_suscrito'], 0, '', '.');
$CapitalIntegrado_s    = number_format($solidaridad['capital_integrado'], 0, '', '.');
$saldo_solidaridad     =  number_format($solidaridad['capital_suscrito'] - $solidaridad['capital_integrado'], 0, '', '.');
$saldo_mora_s        = number_format($solidaridad['saldo_mora'], 0, '', '.');

$capital_pl           = obtener_aporte_local($conn, $resultado['id_cliente']);
$capitalsuscrito_pl   = number_format($capital_pl['capital_suscrito'], 0, '', '.');
$CapitalIntegrado_pl  = number_format($capital_pl['capital_integrado'], 0, '', '.');
$saldo_pl             = number_format($capital_pl['capital_suscrito'] - $capital_pl['capital_integrado'], 0, '', '.');
$saldo_mora_pl        = number_format($capital_pl['saldo_mora'], 0, '', '.');


$prestamos           = obtener_creditos($conn, $resultado['id_cliente']);
$antiguedad  = antiguedad($resultado['fecha_ingreso']);

// Crear una nueva instancia de TCPDF
$pdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);

// Configurar metadatos del documento
$pdf->SetCreator(PDF_CREATOR);
$pdf->SetAuthor('Cooperativa 28 de Febrero Ltda.');
$pdf->SetTitle('Extracto General de Cuentas');
$pdf->SetSubject('Detalle del Extracto');
$pdf->SetKeywords('Extracto, Socio, Cooperativa');

// Configurar márgenes y fuente
$pdf->SetMargins(10, 10, 10);
$pdf->SetHeaderMargin(5);
$pdf->SetFooterMargin(10);
$pdf->SetAutoPageBreak(true, 10);
$pdf->SetFont('helvetica', '', 10);

// Añadir una página
$pdf->AddPage();

// Encabezado
$pdf->SetFont('helvetica', 'B', 12);
$pdf->Cell(0, 8, 'COOPERATIVA 28 DE FEBRERO LTDA.', 0, 1, 'C');
$pdf->SetFont('helvetica', '', 10);
$pdf->Cell(0, 8, 'Extracto General de Cuentas al ' . date('d/m/Y'), 0, 1, 'C');
$pdf->Ln(5);

// Información del socio
// Información del socio con todos los campos en una sola línea
$pdf->SetFont('helvetica', 'B', 10);
$pdf->Cell(0, 6, 'Datos del Socio', 0, 1, 'L');
$pdf->SetFont('helvetica', '', 9);

// Fila con todos los campos
$pdf->Cell(70, 6, 'Nombres y Apellidos:' . $resultado['primer_nombre'] . " " . $resultado['primer_apellido'], 0, 0, 'L');
$pdf->Cell(30, 6, 'Nro Socio:' . $resultado['nro_socio'], 0, 0, 'L');
$pdf->Cell(30, 6, 'Cédula:' . $resultado['cedula'], 0, 0, 'L');
$pdf->Cell(30, 6, 'Estado: ACTIVO', 0, 1, 'L');


$pdf->Cell(70, 6, 'Dirección:' . $resultado['direccion'], 0, 0, 'L');
$pdf->Cell(40, 6, 'Teléfono:' . $resultado['celular'], 0, 0, 'L');
$pdf->Cell(30, 6, 'Fecha de Ingreso:' . date("d-m-Y", strtotime($resultado['fecha_ingreso'])), 0, 1, 'L');


$pdf->Cell(30, 6, 'Antigüedad:' . $antiguedad, 0, 1, 'L');


// Espaciado después de la sección
$pdf->Ln(3);


// Situación General
$pdf->SetFont('helvetica', 'B', 10);
$pdf->Cell(0, 6, 'SITUACIÓN GENERAL', 1, 1, 'C');
$pdf->SetFont('helvetica', '', 9);
//$pdf->MultiCell(0, 6, "PROMEDIO GENERAL: 0,00\nCrédito Disponible: 0\nLímite de Crédito: 0", 1, 'L');
$pdf->Ln(3);

/*************************************************************************************************************/
// Aporte
$pdf->SetFont('helvetica', 'B', 10);
$pdf->Cell(0, 6, 'APORTE', 1, 1, 'C');
$pdf->SetFont('helvetica', '', 9);

$tbl_fondo = <<<EOD
<table border="1" cellpadding="4">
    <tr>
       
        <th style="width: 25%;">Capital Suscripto</th>
        <th style="width: 25%;">Capital Integrado</th>
        <th style="width: 25%;">Deuda Total</th>
        <th style="width: 25%;">Deuda a la Fecha</th>
    </tr>
    <tr>
       
        <td>$capitalsuscrito</td>
        <td>$CapitalIntegrado</td>
        <td>$saldo</td>
         <td>$saldo_mora</td>
    </tr>
</table>
EOD;
$pdf->writeHTML($tbl_fondo, true, false, false, false, '');



// Solidaridad
$pdf->SetFont('helvetica', 'B', 10);
$pdf->Cell(0, 6, 'SOLIDARIDAD', 1, 1, 'C');
$pdf->SetFont('helvetica', '', 9);

$tbl_fondo = <<<EOD
<table border="1" cellpadding="4">
    <tr>
       
       <th style="width: 25%;">Capital Suscripto</th>
        <th style="width: 25%;">Capital Integrado</th>
        <th style="width: 25%;">Deuda Total</th>
        <th style="width: 25%;">Deuda a la Fecha</th>
    </tr>
    <tr>
       
        <td>$capitalsuscrito_s</td>
        <td>$CapitalIntegrado_s</td>
        <td>$saldo_solidaridad</td>
        <td>$saldo_mora_s</td>
    </tr>
</table>
EOD;
$pdf->writeHTML($tbl_fondo, true, false, false, false, '');


// Fondo de Construcción
$pdf->SetFont('helvetica', 'B', 10);
$pdf->Cell(0, 6, 'FONDO DE CONSTRUCCIÓN', 1, 1, 'C');
$pdf->SetFont('helvetica', '', 9);

$tbl_fondo = <<<EOD
<table border="1" cellpadding="4">
    <tr>
       
   <th style="width: 25%;">Capital Suscripto</th>
        <th style="width: 25%;">Capital Integrado</th>
        <th style="width: 25%;">Deuda Total</th>
        <th style="width: 25%;">Deuda a la Fecha</th>
    </tr>
    <tr>
       
        <td>$capitalsuscrito_pl</td>
        <td>$CapitalIntegrado_pl</td>
        <td>$saldo_pl</td>
        <td>$saldo_mora_pl</td>
    </tr>
</table>
EOD;
$pdf->writeHTML($tbl_fondo, true, false, false, false, '');




// Créditos Activos
$pdf->Ln(3);
$pdf->SetFont('helvetica', 'B', 10);
$pdf->Cell(0, 6, 'CRÉDITOS ACTIVOS', 1, 1, 'C');
$pdf->SetFont('helvetica', '', 8);

$tbl_creditos = <<<EOD
<table border="1" cellpadding="4">
    <tr>
        <th style="width: 10%;">N° Oper.</th>
        <th style="width: 20%;">Tipo Operación</th>
        <th style="width: 10%;">Fecha Liqu.</th>
        <th style="width: 10%;">CA/CC/TC</th>
        <th style="width: 10%;">Vencimiento</th>
        <th style="width: 20%;">Monto</th>
        <th style="width: 20%;">Saldo</th>
    </tr> 
EOD;

// Generar filas dinámicas con foreach
foreach ($prestamos as $prestamo) {
  $monto           = number_format($prestamo['monto_total'], 0, '', '.');
  $monto_pendiente = number_format($prestamo['monto_pendiente'], 0, '', '.');
  $fecha_credito   = date("d-m-Y", strtotime($prestamo['fecha_credito']));
  $vencimiento   = date("d-m-Y", strtotime($prestamo['vencimiento']));

  //echo date("d-m-Y",strtotime($row['inicio'])); 
  $tbl_creditos .= <<<EOD
    <tr>
        <td>{$prestamo['nro_credito']}</td>
        <td>{$prestamo['tipo_credito']}</td>
        <td>{$fecha_credito}</td>
         <td>{$prestamo['estado_cuotas']}</td>
         <td>{$vencimiento}</td>
        <td>{$monto}</td>
        <td>{$monto_pendiente}</td>
    </tr>
    EOD;
};


// Cerrar tabla
$tbl_creditos .= "</table>";

$pdf->writeHTML($tbl_creditos, true, false, false, false, '');

// Pie de página

$pdf->Ln(10);
$pdf->SetFont('helvetica', '', 5);
$pdf->Cell(0, 6, 'CA = Cuotas Atrasadas; CC = Cuotas Canceladas; TC = Total Cuotas; F.Liq = Fecha Desembolso; F. Vto = Fecha de Venc 1ra. Cuota. Los montos de intereses Moratorios y Punitorios incluyen IVA', 0, 1, 'C');


$pdf->Ln(10);
$pdf->SetFont('helvetica', '', 8);
$pdf->Cell(0, 10, '*** FIN DEL INFORME ***', 0, 1, 'C');



// Salida del archivo PDF
$pdf->Output('extracto_socio_formulario.pdf', 'I');





function obtener_aporte($conn, $id_cliente)
{

  // Definir y inicializar las variables
  $capital_suscrito = 0;   // Inicializar capital suscrito
  $capital_integrado = 0;   // Inicializar capital integrado
  $saldo_mora = 0;


  $sql = "SELECT  *
  from cuenta_corriente 
  where id_cliente    = :id_cliente
  and id_empresa      = :id_empresa 
  and clase_documento = :clase_documento";
  $stmt = $conn->prepare($sql);
  $stmt->execute(array(
    ':id_cliente' =>  $id_cliente,
    ':id_empresa' =>  $_SESSION['id_empresa'],
    ':clase_documento' => 'AP'
  ));
  $resultado = $stmt->fetchAll();
  if ($resultado) {
    $deudas = [];
    foreach ($resultado as $row) {

      $capital_suscrito += $row['importe'];


      if ($row['estado'] == 1) {
        $capital_integrado += $row['importe'];
      }


      if ($row['vencimiento'] < date("Y-m-d") and $row['estado'] == 0) {
        $saldo_mora += $row['importe'];
      }
    }

    // Retornar los valores calculados
    return [
      'capital_suscrito' => $capital_suscrito,
      'capital_integrado' => $capital_integrado,
      'saldo_mora' => $saldo_mora
    ];
  }
}


function obtener_solidaridad($conn, $id_cliente)
{

  // Definir y inicializar las variables
  $capital_suscrito = 0;   // Inicializar capital suscrito
  $capital_integrado = 0;   // Inicializar capital integrado
  $saldo_mora = 0;

  $sql = "SELECT  *
  from cuenta_corriente 
  where id_cliente    = :id_cliente
  and id_empresa      = :id_empresa 
  and clase_documento = :clase_documento";
  $stmt = $conn->prepare($sql);
  $stmt->execute(array(
    ':id_cliente' =>  $id_cliente,
    ':id_empresa' =>  $_SESSION['id_empresa'],
    ':clase_documento' => 'AS'
  ));
  $resultado = $stmt->fetchAll();
  if ($resultado) {
    
    foreach ($resultado as $row) {

      $capital_suscrito += $row['importe'];


      if ($row['estado'] == 1) {
        $capital_integrado += $row['importe'];
      }


      if ($row['vencimiento'] < date("Y-m-d") and $row['estado'] == 0) {
        $saldo_mora += $row['importe'];
      }
    }

    // Retornar los valores calculados
    return [
      'capital_suscrito' => $capital_suscrito,
      'capital_integrado' => $capital_integrado,
      'saldo_mora' => $saldo_mora
    ];
  }
}


function obtener_aporte_local($conn, $id_cliente)
{

  // Definir y inicializar las variables
  $capital_suscrito = 0;   // Inicializar capital suscrito
  $capital_integrado = 0;   // Inicializar capital integrado
  $saldo_mora = 0;

  $sql = "SELECT  *
  from cuenta_corriente 
  where id_cliente    = :id_cliente
  and id_empresa      = :id_empresa 
  and clase_documento = :clase_documento";
  $stmt = $conn->prepare($sql);
  $stmt->execute(array(
    ':id_cliente' =>  $id_cliente,
    ':id_empresa' =>  $_SESSION['id_empresa'],
    ':clase_documento' => 'PL'
  ));
  $resultado = $stmt->fetchAll();
  if ($resultado) {

    foreach ($resultado as $row) {

      $capital_suscrito += $row['importe'];


      if ($row['estado'] == 1) {
        $capital_integrado += $row['importe'];
      }


      if ($row['vencimiento'] < date("Y-m-d") and $row['estado'] == 0) {
        $saldo_mora += $row['importe'];
      }
    }
  
    // Retornar los valores calculados
    return [
      'capital_suscrito' => $capital_suscrito,
      'capital_integrado' => $capital_integrado,
      'saldo_mora'        => $saldo_mora
    ];
  }
}


function antiguedad($ingreso)
{

  $fechaIngreso = new DateTime($ingreso); // Cambia la fecha según corresponda

  // Fecha actual
  $fechaActual = new DateTime(); // Obtiene la fecha actual

  // Calcular la diferencia
  $diferencia = $fechaIngreso->diff($fechaActual);

  // Formatear la antigüedad
  $antiguedad = '';
  if ($diferencia->y > 0) {
    $antiguedad .= $diferencia->y . ' años ';
  }
  if ($diferencia->m > 0) {
    $antiguedad .= $diferencia->m . ' meses ';
  }
  if ($diferencia->d > 0) {
    $antiguedad .= $diferencia->d . ' días';
  }

  // Resultado
  $antiguedad = trim($antiguedad);
  return  $antiguedad;
  //echo "Antigüedad: " . trim($antiguedad);

}




function obtener_creditos($conn, $id_cliente)
{
  // Inicialización de variables
  $prestamos = array();

  $sql = "SELECT a.*, b.nombre as tipo_credito
            FROM cuenta_corriente as a
            INNER JOIN tipo_credito as b
            ON a.tipo_credito = b.id
            WHERE a.id_cliente = :id_cliente
            AND a.id_empresa = :id_empresa
            AND a.clase_documento = :clase_documento
            AND nro_documento IN (SELECT nro_documento FROM cuenta_corriente WHERE id_cliente = :id_cliente AND clase_documento = :clase_documento)";

  $stmt = $conn->prepare($sql);
  $stmt->execute(array(
    ':id_cliente' => $id_cliente,
    ':id_empresa' => $_SESSION['id_empresa'],
    ':clase_documento' => 'PT'
  ));

  $resultado = $stmt->fetchAll();

  if ($resultado) {
    // Agrupar por nro_credito
    foreach ($resultado as $row) {
      // Si el crédito aún no está en el array, lo inicializamos
      $nro_credito = $row['nro_credito'];
      if (!isset($prestamos[$nro_credito])) {
        $prestamos[$nro_credito] = [
          'monto_total' => 0,
          'monto_pendiente' => 0,
          'cuota_atrasada' => 0,
          'cuotas_pagadas' => 0,
          'cuotas_pendientes' => 0,
          'cuotas_total' => 0,
          'fecha_credito' => $row['fecha'],
          'tipo_credito' => $row['tipo_credito'],
          'vencimiento' => $row['vencimiento']
        ];
      }

      // Actualizamos los valores del préstamo agrupado
      $prestamos[$nro_credito]['monto_total'] += $row['importe'];
      $prestamos[$nro_credito]['cuotas_total']++;

      if ($row['estado'] == 0) {
        $prestamos[$nro_credito]['monto_pendiente'] += $row['importe'];
        $prestamos[$nro_credito]['cuotas_pendientes']++;
      }

      if ($row['estado'] == 1) {
        $prestamos[$nro_credito]['cuotas_pagadas']++;
      }

      // Verificamos si la cuota está atrasada
      if ($row['vencimiento'] < date("Y-m-d")) {
        $prestamos[$nro_credito]['cuota_atrasada']++;
      }
    }

    // Preparar el estado de cuotas y los datos finales
    $resultados_finales = array();
    foreach ($prestamos as $nro_credito => $data) {
      $estado_cuotas = $data['cuota_atrasada'] . "/" . $data['cuotas_pagadas'] . "/" . $data['cuotas_total'];
      $resultados_finales[] = [
        'nro_credito' => $nro_credito,
        'monto_total' => $data['monto_total'],
        'monto_pendiente' => $data['monto_pendiente'],
        'fecha_credito' => $data['fecha_credito'],
        'tipo_credito' => $data['tipo_credito'],
        'cuota_atrasada' => $data['cuota_atrasada'],
        'cuotas_pagadas' => $data['cuotas_pagadas'],
        'cuotas_pendientes' => $data['cuotas_pendientes'],
        'cuotas_total' => $data['cuotas_total'],
        'estado_cuotas' => $estado_cuotas,
        'vencimiento' => $data['vencimiento']
      ];
    }

    // Retornar los resultados
    return $resultados_finales;
  }

  return null; // Si no se encuentra ningún resultado
}
